#! /usr/bin/env ruby
#
#  check-bonding-status
#
# DESCRIPTION:
#   This is a simple bonding check script for Sensu.
#
# OUTPUT:
#   plain text
#
# PLATFORMS:
#   Linux
#
# DEPENDENCIES:
#   gem: sensu-plugin
#
# USAGE:
#   check-bonding-status
#
# NOTES:
#   Shamelessly stolen, copied and rubified from
#   http://folk.uio.no/trondham/software/check_linux_bonding.html
#
# LICENSE:
#   Jens Rosenboom <j.rosenboom@x-ion.de>
#   Released under the same terms as Sensu (the MIT license); see LICENSE
#   for details.
#

require 'rubygems' if RUBY_VERSION < '1.9.0'
require 'sensu-plugin/check/cli'

class CheckBonding < Sensu::Plugin::Check::CLI
  def run
    sysdir = '/sys/class/net'
    masters_file = "#{sysdir}/bonding_masters"
    result = []

    if File.exists?(masters_file)
      bonds = File.open(masters_file,'r') { |f|
        f.readlines[0].split(' ')
      }

      bonds.each { |bond|
        next if bond == 'bond0'
        mode = File.open("#{sysdir}/#{bond}/bonding/mode",'r') { |f|
          f.readlines[0].split(' ')
        }

        if mode[1]=="0"
          msg = "#{bond} has mode #{mode[0]}/#{mode[1]}"
          result.push(msg)
        end
      }
    end

    if result.size == 0
      success_message = 'All bonding modes are o.k.'
      ok success_message
    else
      failure_message = "Bonding modes wrong: #{result.to_s}"
      critical failure_message
    end
  end
end

