#!/usr/bin/env ruby
#
# Check OpenStack Hypervisors
# ===========================
#
# Test: sudo /opt/sensu/embedded/bin/ruby ./check-hypervisor.rb

require 'rubygems' if RUBY_VERSION < '1.9.0'
require 'sensu-plugin/check/cli'
require 'timeout'
require 'English'
require 'open3'

class CheckHypervisor < Sensu::Plugin::Check::CLI

  option :timeout,
    :description => 'Timeout (default 10)',
    :short => '-t SEC',
    :long => '--timeout',
    :proc => proc { |t| t.to_i },
    :default => 10

  # Parse /root/openrc to produce credentials hash
  def get_cred_vars
    openrc = '/root/openrc'
    cred_vars = {}
    File.readlines(openrc).each do |line|
      next unless line.start_with?('export ')
      key, val = line.scan(/export (.*)=(.*)/)[0]
      cred_vars[key] = val
    end
    cred_vars
  end

  def run_cmd(env, *cmd)
    output, status = nil
    begin
      Timeout.timeout(config[:timeout]) do
        Open3.popen2e(env, *cmd) { |i, out_err, wait_thr|
          output = out_err.read
          status = wait_thr.value
        }
      end
    rescue Timeout::Error
      critical "Error: timed out waiting for #{cmd}"
    end

    critical "Command '#{cmd}' returned no output" if output.to_s == ''
    critical output unless status == 0
    # output contains one line per hypervisor. Example line:
    # 5 compute-node20.dev.berlin.x-ion.de QEMU 10.250.0.20 up
    # No line must end in 'down'.
    if output.match(' down$')
      msg = "Hypervisor down. Maybe restart nova-compute on compute node?\n"
      critical msg + output
    end
    output
  end

  def run
    env = get_cred_vars
    result = run_cmd(env, "openstack", "hypervisor", "list", "-fvalue")
    ok result
  end
end
