#! /usr/bin/env ruby
#
#  check-interface-status
#
# DESCRIPTION:
#   This is a simple interface check script for Sensu.
#
# OUTPUT:
#   plain text
#
# PLATFORMS:
#   Linux
#
# DEPENDENCIES:
#   gem: sensu-plugin
#
# USAGE:
#   check-interface-status
#
# NOTES:
#
# LICENSE:
#   Jens Rosenboom <j.rosenboom@x-ion.de>
#   Released under the same terms as Sensu (the MIT license); see LICENSE
#   for details.
#

require 'rubygems' if RUBY_VERSION < '1.9.0'
require 'sensu-plugin/check/cli'

class CheckInterfaces < Sensu::Plugin::Check::CLI
  def run
    # All our physical interfaces are used in bonds named something like
    # xiondata, xionpublic or xionbackend (+ maybe the vlan). To filter out all
    # intefaces created by ovs and only check for the ones created by us, we
    # grep for xion here (which will yield all bonds and all interfaces used in
    # bonds).
    # example on a compute-node:
    # (dev_hh) root@compute-node19:~# ip link show | grep xion
    # 2: ge0: <BROADCAST,MULTICAST,SLAVE,UP,LOWER_UP> mtu 1500 qdisc mq master xionmgmt state UP mode DEFAULT group default qlen 1000
    # 3: ge1: <BROADCAST,MULTICAST,SLAVE,UP,LOWER_UP> mtu 1500 qdisc mq master xionmgmt state UP mode DEFAULT group default qlen 1000
    # 4: xge0: <BROADCAST,MULTICAST,SLAVE,UP,LOWER_UP> mtu 1550 qdisc mq master xiondata state UP mode DEFAULT group default qlen 1000
    # 5: xge1: <BROADCAST,MULTICAST,SLAVE,UP,LOWER_UP> mtu 1550 qdisc mq master xiondata state UP mode DEFAULT group default qlen 1000
    # 12: xionmgmt: <BROADCAST,MULTICAST,MASTER,UP,LOWER_UP> mtu 1500 qdisc noqueue state UP mode DEFAULT group default qlen 1000
    # 13: xiondata: <BROADCAST,MULTICAST,MASTER,UP,LOWER_UP> mtu 1550 qdisc noqueue master ovs-system state UP mode DEFAULT group default qlen 1000
    # 14: xiondata.200@xiondata: <BROADCAST,MULTICAST,UP,LOWER_UP> mtu 1550 qdisc noqueue state UP mode DEFAULT group default qlen 1000
    result = `ip link show | grep xion | grep NO-CARRIER`

    if result == ''
      success_message = 'All interfaces are o.k.'
      ok success_message
    else
      failure_message = "Interfaces down: #{result}"
      critical failure_message
    end
  end
end

