#!/usr/bin/env ruby
#
# Check systemd services
# ===
#
# Examples:
#
#    # neutron-server service is running
#    check-service -s neutron-server
#
#    # nova-network service is NOT running
#    check-service --no-running -s neutron-server
#
# Copyright 2015 x-ion GmbH, <info@x-ion.de>
#
# Released under the same terms as Sensu (the MIT license); see LICENSE
# for details.

require 'rubygems' if RUBY_VERSION < '1.9.0'
require 'sensu-plugin/check/cli'
require 'timeout'
require 'json'

class NeutronAgentStatus < Sensu::Plugin::Check::CLI

  option :command,
    :short => '-c COMMAND',
    :long => '--command COMAND'

  option :timeout,
    :description => 'Timeout (default 10)',
    :short => '-t SEC',
    :long => '--timeout',
    :proc => proc { |t| t.to_i },
    :default => 10

  def run_cmd(cmd)
    begin
      output, status = nil
      Timeout.timeout(config[:timeout]) do
        output = `#{cmd}`
        status = $?.success?
      end
    rescue => error
      critical "Error: #{error.to_s}"
    end
    JSON.parse output
  end

  def run
    agent_up = []
    agent_down_names = []
    agent_down = []
    agent_intentionally_down = []
    output = run_cmd config[:command]
    agent_down = output.select { |agent| agent['Alive'] == 'XXX' && agent['State'] == 'UP' }
    agent_intentionally_down = output.select { |agent| agent['Alive'] == 'XXX' && agent['State'] == 'DOWN' }
    agent_down.each do |agent|
      agent_down_names.push "#{agent['Agent Type']} on Host: #{agent['Host']}"
    end
    critical "Agents #{output.size} Total / #{agent_down_names.size} Down \nAgents: #{agent_down_names} are down" if agent_down.size > 0
    warn "Agents #{output.size} Total / #{agent_down_names.size} Down \nAgents: #{agent_down_names} are down" if agent_intentionally_down.size > 0
    ok "Agents #{output.size} Total / #{agent_down_names.size} Down"
  end
end
