#!/usr/bin/env ruby
#
# Percona Cluster Local Check Plugin
# ===
#
# This plugin checks the status of a single servers in the Percona cluster and warns you according to specified limits
#
# Stolen from:
# Copyright 2012 Chris Alexander <chris.alexander@import.io>, import.io
# Based on the MySQL Health Plugin by Panagiotis Papadomitsos
# and modified for own purposes.
#
# Depends on mysql:
# gem install mysql
#
# Released under the same terms as Sensu (the MIT license); see LICENSE
# for details.

require 'rubygems' if RUBY_VERSION < '1.9.0'
require 'sensu-plugin/check/cli'
require 'mysql'

class CheckPerconaClusterLocal < Sensu::Plugin::Check::CLI

  option :user,
         :description => "MySQL User",
         :short => '-u USER',
         :long => '--user USER',
         :default => 'clustercheckuser'

  option :password,
         :description => "MySQL Password",
         :short => '-p PASS',
         :long => '--password PASS',
         :default => 'clustercheckpassword!'

  option :hostname,
         :description => "Hostname to login to",
         :short => '-h HOST',
         :long => '--hostname HOST',
         :default => 'localhost'

  option :expected,
         :description => "Server status expected",
         :short => '-e NUMBER',
         :long => '--expected NUMBER',
         :default => 4
  
  option :socket,
         :description => "mysqld socket",
         :short => '-s SOCKET',
         :long => '--socket SOCKET',
         :default => '/var/run/mysqld/mysqld.sock'

  def run
    begin
      db = Mysql.real_connect(config[:hostname], config[:user], config[:password], config[:database], nil, config[:socket])
      server_status = db.
          query("SHOW STATUS LIKE 'wsrep_local_state'").
          fetch_hash.
          fetch('Value').
          to_i
      critical "Expected server status #{config[:expected]} and found #{server_status}" if server_status != config[:expected].to_i
      ok "Expected server status #{config[:expected]} and found #{server_status}" if server_status == config[:expected].to_i
    rescue Mysql::Error => e
      critical "Percona MySQL check failed: #{e.error}"
    ensure
      db.close if db
    end
  end

end
