#! /usr/bin/env ruby
#
#  check-routes
#
# DESCRIPTION:
#   This checks if all routes are set properly.
#
# OUTPUT:
#   plain text
#
# PLATFORMS:
#   Linux
#
# DEPENDENCIES:
#   gem: sensu-plugin
#
# USAGE:
#   check-routes
#
# NOTES:
#
# LICENSE:
#   Jan Klare <j.klare@x-ion.de>
#   Released under the same terms as Sensu (the MIT license); see LICENSE
#   for details.
#

require 'rubygems' if RUBY_VERSION < '1.9.0'
require 'sensu-plugin/check/cli'

class CheckRoutes < Sensu::Plugin::Check::CLI

  option :route,
         short: '-r ROUTE',
         description: 'ip route that should be checked'

  def run
    routes = `ip route`.split("\n")

    if routes.any? { |s| s.include? "#{config[:route]}" }
      success_message = "ROUTE: #{config[:route]} exists"
      ok success_message
    else
      failure_message = "ROUTE: #{config[:route]} doesn't exist"
      critical failure_message
    end
  end
end
